@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2007, 
-   2008 Free Software Foundation, Inc.
+   2008, 2009 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,11 +37,8 @@
 #include <syslog.h>
 #include <string.h>
 #include <pwd.h>
-#include <ctype.h>
 
-#ifdef HAVE_PATHS_H
-# include <paths.h>
-#endif
+#include <confpaths.h>
 
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
@@ -63,6 +60,7 @@
 #include <mailutils/daemon.h>
 #include <mailutils/acl.h>
 #include <mailutils/server.h>
+#include <mailutils/cctype.h>
 
 #ifndef INADDR_NONE
 # define INADDR_NONE -1
