@@ -1,9 +1,9 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2004, 2006 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2004, 2007 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Mailutils is distributed in the hope that it will be useful,
@@ -20,6 +20,9 @@
    It connects to a remote HTTP server and prints the contents of its
    index page */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -96,7 +99,7 @@ main (int argc, char **argv)
     {
       if ((ret == EAGAIN || ret == EINPROGRESS) && attempt < io_attempts)
 	{
- 	  ret = http_stream_wait(stream, MU_STREAM_READY_WR, &attempt);
+	  ret = http_stream_wait(stream, MU_STREAM_READY_WR, &attempt);
 	  if (ret == 0)
 	    continue;
 	}
