@@ -16,11 +16,13 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301 USA */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
 #include <stdlib.h>
-#include <mailutils/mutil.h>
-#include <mailutils/argp.h>
-
 #include <stdio.h>
+#include <mailutils/mutil.h>
+#include "mailutils/libargp.h"
 
 const char *capa[] = {
   "address",
@@ -32,8 +34,8 @@ main (int argc, char *argv[])
 {
   int arg = 1;
 
-  if (mu_argp_parse (NULL, &argc, &argv, 0, capa, &arg, NULL))
-    abort ();
+  if (mu_app_init (NULL, capa, NULL, argc, argv, 0, &arg, NULL))
+    exit (1);
 
   if (!argv[arg])
     printf ("current user -> %s\n", mu_get_user_email (0));
