@@ -2,7 +2,7 @@
    GNU Mailutils nntp functions.  This application interactively allows users
    to contact a nntp server.
 
-   Copyright (C) 2003, 2004, 2005, 2007 Free Software Foundation
+   Copyright (C) 2003, 2004, 2005, 2007, 2009 Free Software Foundation
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 #include <stdlib.h>
 #include <termios.h>
 #include <signal.h>
-#include <ctype.h>
 #include <time.h>
 
 #ifdef WITH_READLINE
@@ -43,6 +42,9 @@
 #include <mailutils/iterator.h>
 #include <mailutils/error.h>
 #include <mailutils/errno.h>
+#include <mailutils/mutil.h>
+#include <mailutils/cctype.h>
+#include <mailutils/cstr.h>
 
 /* A structure which contains information on the commands this program
    can understand. */
@@ -86,7 +88,6 @@ int com_stat (char *);
 int com_verbose (char *);
 
 void initialize_readline (void);
-char *stripwhite (char *);
 COMMAND *find_command (char *);
 char *dupstr (const char *);
 int execute_line (char *);
@@ -273,7 +274,7 @@ main (int argc MU_ARG_UNUSED, char **argv)
       /* Remove leading and trailing whitespace from the line.
          Then, if there is anything left, add it to the history list
          and execute it. */
-      s = stripwhite (line);
+      s = mu_str_stripws (line);
 
       if (*s)
 	{
@@ -293,45 +294,34 @@ main (int argc MU_ARG_UNUSED, char **argv)
 int
 execute_line (char *line)
 {
-  register int i;
   COMMAND *command;
-  char *word;
+  char *word, *arg;
 
   /* Isolate the command word. */
-  i = 0;
-  while (line[i] && isspace (line[i]))
-    i++;
-  word = line + i;
-
-  while (line[i] && !isspace (line[i]))
-    i++;
-
-  if (line[i])
-    line[i++] = '\0';
-
+  word = mu_str_skip_class (line, MU_CTYPE_SPACE);
+  arg = mu_str_skip_class_comp (word, MU_CTYPE_SPACE);
+  if (*arg)
+    {
+      *arg++ = 0;
+      arg = mu_str_skip_class (arg, MU_CTYPE_SPACE);
+    }
+      
   command = find_command (word);
 
   if (!command)
     {
-      fprintf (stderr, "%s: No such command for %s.\n", word, progname);
-      return (-1);
+      mu_error ("%s: No such command.", word);
+      return 0;
     }
 
-  /* Get argument to command, if any. */
-  while (isspace (line[i]))
-    i++;
-
-  word = line + i;
-
   /* Call the function. */
-  return ((*(command->func)) (word));
+  return ((*(command->func)) (arg));
 }
 
 /* Look up NAME as the name of a command, and return a pointer to that
    command.  Return a NULL pointer if NAME isn't a command name. */
 COMMAND *
-find_command (name)
-     char *name;
+find_command (char *name)
 {
   register int i;
 
@@ -342,27 +332,6 @@ find_command (name)
   return ((COMMAND *) NULL);
 }
 
-/* Strip whitespace from the start and end of STRING.  Return a pointer
-   into STRING. */
-char *
-stripwhite (char *string)
-{
-  register char *s, *t;
-
-  for (s = string; isspace (*s); s++)
-    ;
-
-  if (*s == 0)
-    return (s);
-
-  t = s + strlen (s) - 1;
-  while (t > s && isspace (*t))
-    t--;
-  *++t = '\0';
-
-  return s;
-}
-
 int
 com_verbose (char *arg)
 {
@@ -392,7 +361,7 @@ int com_mode (char *arg)
 {
   if (!valid_argument("mode", arg))
     return EINVAL;
-  if (strncasecmp (arg, "READER", 6) == 0)
+  if (mu_c_strncasecmp (arg, "READER", 6) == 0)
     return com_mode_reader (arg);
   return EINVAL;
 }
@@ -533,27 +502,27 @@ int com_list (char *arg)
     {
       status = com_list_active (arg);
    }
-  else if (strncasecmp (keyword, "ACTIVE.TIMES", 12) == 0)
+  else if (mu_c_strncasecmp (keyword, "ACTIVE.TIMES", 12) == 0)
     {
       status = com_list_active_times (arg);
     }
-  else if (strncasecmp (keyword, "ACTIVE", 6) == 0)
+  else if (mu_c_strncasecmp (keyword, "ACTIVE", 6) == 0)
     {
       status = com_list_active (arg);
     }
-  else if (strncasecmp (keyword, "EXTENSIONS", 10) == 0)
+  else if (mu_c_strncasecmp (keyword, "EXTENSIONS", 10) == 0)
     {
       status = com_list_extensions (arg);
     }
-  else if (strncasecmp (keyword, "DISTRIBUTIONS", 13) == 0)
+  else if (mu_c_strncasecmp (keyword, "DISTRIBUTIONS", 13) == 0)
     {
       status = com_list_distributions (arg);
     }
-  else if (strncasecmp (keyword, "DISTRIB.PATS", 12) == 0)
+  else if (mu_c_strncasecmp (keyword, "DISTRIB.PATS", 12) == 0)
     {
       status = com_list_distrib_pats (arg);
     }
-  else if (strncasecmp (keyword, "NEWSGROUPS", 10) == 0)
+  else if (mu_c_strncasecmp (keyword, "NEWSGROUPS", 10) == 0)
     {
       status = com_list_newsgroups (arg);
     }
@@ -806,7 +775,7 @@ com_newgroups (char *arg)
       char gmt[4];
       memset (gmt, 0, 4);
       sscanf (arg, "%4d%2d%2d %2d%2d%2d %3s", &year, &month, &day, &hour, &min, &sec, gmt);
-      is_gmt = strncasecmp ("GMT", gmt, 3) == 0;
+      is_gmt = mu_c_strncasecmp ("GMT", gmt, 3) == 0;
     }
 
   /* If nothing defined take the current time.  */
@@ -865,7 +834,7 @@ com_newnews (char *arg)
 
   wildmat = calloc (1, 512);
   sscanf (arg, "%511s %4d%2d%2d %2d%2d%2d %3s", wildmat, &year, &month, &day, &hour, &min, &sec, gmt);
-  is_gmt = strncasecmp ("GMT", gmt, 3) == 0;
+  is_gmt = mu_c_strncasecmp ("GMT", gmt, 3) == 0;
 
   if (year == 0)
     {
