@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2005, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2005, 2007, 2008,
+   2009 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,92 +19,74 @@
 
 #include "imap4d.h"
 
-/*FIXME: should be global? */
 typedef int (*nsfp_t) (void *closure, int ns, char *path, int delim);
 
-struct namespace_t
+mu_list_t namespace[NS_MAX];
+
+static const char *
+printable_pathname (const char *str)
 {
-  int subdir_c;
-  char **subdir_v;
-};
-
-struct namespace_t namespace[NS_MAX];
-
-/* Note: str is not supposed to be NULL */
-int
-set_namespace (int i, char *str)
-{
-  char *p, *save;
-  struct namespace_t ns;
-
-  /* first, estimate the number of items in subdir_v array: */
-  ns.subdir_c = 1;
-  for (p = strchr (str, ':'); p && *p; p = strchr (p + 1, ':'))
-    ns.subdir_c++;
-
-  /* Now allocate the memory */
-  ns.subdir_v = calloc (ns.subdir_c, sizeof (ns.subdir_v[0]));
-
-  /* Fill in the array */
-  if (ns.subdir_c == 1)
+  if (strncmp (str, imap4d_homedir, strlen (imap4d_homedir)) == 0)
     {
-      ns.subdir_v[0] = mu_normalize_path (strdup (str), "/");
-    }
-  else
-    {
-      ns.subdir_c = 0;
-      for (p = strtok_r (str, ":", &save); p; p = strtok_r (NULL, ":", &save))
-	{
-	  ns.subdir_v[ns.subdir_c++] = mu_normalize_path (strdup (p), "/");
-	}
-    }
-
-  namespace[i] = ns;
-
-  return 0;
-}
-
-static char *
-printable_pathname (char *str)
-{
-  if (strncmp (str, homedir, strlen (homedir)) == 0)
-    {
-      str += strlen (homedir);
+      str += strlen (imap4d_homedir);
       if (str[0] == '/')
 	str++;
     }
   return str;
 }
 
-static void
-print_namespace (int n)
+static int
+print_namespace_fun (void *item, void *data)
 {
-  int i;
-
-  if (namespace[n].subdir_c == 0)
-    {
-      util_send ("NIL");
-      return;
-    }
-
-  util_send ("(");
-  for (i = 0; i < namespace[n].subdir_c; i++)
-    {
-      util_send ("(\"%s\" \"/\")",
-		 printable_pathname (namespace[n].subdir_v[i]));
-    }
-  util_send (")");
+  int *pcount = data;
+  const char *dir = printable_pathname (item);
+  char *suf = (dir[0] && dir[strlen (dir) - 1] != '/') ? "/" : "";
+  if ((*pcount)++)
+    util_send (" ");
+  util_send ("(\"%s%s\" \"/\")", dir, suf);
+  return 0;
 }
 
-static int
-namespace_enumerate (int ns, nsfp_t f, void *closure)
+static void
+print_namespace (int nsid)
 {
-  int i, rc;
+  mu_list_t list = namespace[nsid];
+  if (!list)
+    util_send ("NIL");
+  else
+    {
+      int count;
+      count = 0;
+      util_send ("(");
+      mu_list_do (list, print_namespace_fun, &count);
+      util_send (")");
+    }
+}
 
-  for (i = 0; i < namespace[ns].subdir_c; i++)
-    if ((rc = (*f) (closure, ns, namespace[ns].subdir_v[i], '/')))
-      return rc;
-  return 0;
+struct ns_closure
+{
+  int id;
+  nsfp_t fun;
+  void *closure;
+};
+
+static int
+_enum_fun (void *item, void *data)
+{
+  struct ns_closure *nsp = data;
+  return nsp->fun (nsp->closure, nsp->id, (char*) item, '/');
+}
+  
+static int
+namespace_enumerate (int id, nsfp_t f, void *closure)
+{
+  struct ns_closure nsc;
+
+  nsc.id = id;
+  nsc.fun = f;
+  nsc.closure = closure;
+  return namespace[id] == 0 ? 0 :
+          mu_list_do (namespace[id], _enum_fun, &nsc);
 }
 
 static int
@@ -114,11 +97,27 @@ namespace_enumerate_all (nsfp_t f, void *closure)
     || namespace_enumerate (NS_SHARED, f, closure);
 }
 
+/*
+5. NAMESPACE Command
+
+   Arguments: none
+
+   Response:  an untagged NAMESPACE response that contains the prefix
+                 and hierarchy delimiter to the server's Personal
+                 Namespace(s), Other Users' Namespace(s), and Shared
+                 Namespace(s) that the server wishes to expose. The
+                 response will contain a NIL for any namespace class
+                 that is not available. Namespace_Response_Extensions
+                 MAY be included in the response.
+                 Namespace_Response_Extensions which are not on the IETF
+                 standards track, MUST be prefixed with an "X-".
+*/
+
 int
-imap4d_namespace (struct imap4d_command *command, char *arg)
+imap4d_namespace (struct imap4d_command *command, imap4d_tokbuf_t tok)
 {
-  if (*arg)
-    return util_finish (command, RESP_BAD, "Too many arguments");
+  if (imap4d_tokbuf_argc (tok) != 2)
+    return util_finish (command, RESP_BAD, "Invalid arguments");
 
   util_send ("* NAMESPACE ");
 
@@ -132,7 +131,7 @@ imap4d_namespace (struct imap4d_command *command, char *arg)
   return util_finish (command, RESP_OK, "Completed");
 }
 
-
+
 struct namespace_info
 {
   char *name;
@@ -168,10 +167,12 @@ risky_pattern (const char *pattern, int delim)
 }
 
 char *
-namespace_checkfullpath (char *name, const char *pattern, const char *delim)
+namespace_checkfullpath (const char *name, const char *pattern, 
+			 const char *delim, int *nspace)
 {
   struct namespace_info info;
-  char *p, *path = NULL;
+  const char *p;
+  char *path = NULL;
   char *scheme = NULL;
 
   p = strchr (name, ':');
@@ -209,6 +210,8 @@ namespace_checkfullpath (char *name, const char *pattern, const char *delim)
       return NULL;
     }
 
+  if (nspace)
+    *nspace = info.ns;
   if (scheme)
     {
       char *pathstr = malloc (strlen (scheme) + strlen (path) + 2);
@@ -225,18 +228,61 @@ namespace_checkfullpath (char *name, const char *pattern, const char *delim)
 }
 
 char *
-namespace_getfullpath (char *name, const char *delim)
+namespace_getfullpath (const char *name, const char *delim, int *nspace)
 {
-  if (strcasecmp (name, "INBOX") == 0 && auth_data->change_uid)
-    name = strdup (auth_data->mailbox);
+  char *ret;
+  if (mu_c_strcasecmp (name, "INBOX") == 0 && auth_data->change_uid)
+    {
+      ret = strdup (auth_data->mailbox);
+      if (nspace)
+	*nspace = NS_PRIVATE;
+    }
   else
-    name = namespace_checkfullpath (name, NULL, delim);
-  return name;
+    ret = namespace_checkfullpath (name, NULL, delim, nspace);
+  return ret;
 }
 
 int
-namespace_init (char *path)
+namespace_init_session (char *path)
 {
-  set_namespace (NS_PRIVATE, path);
+  if (!namespace[NS_PRIVATE])
+    mu_list_create (&namespace[NS_PRIVATE]);
+  mu_list_prepend (namespace[NS_PRIVATE],
+		   mu_strdup (mu_normalize_path (path)));
   return 0;
 }
+
+static int
+normalize_fun (void *item, void *data)
+{
+  char *name = item;
+  mu_list_t list = data;
+  return mu_list_append (list,
+			 mu_strdup (mu_normalize_path (name)));
+}
+
+static void
+free_item (void *item)
+{
+  free (item);
+}
+  
+void
+namespace_init ()
+{
+  int i;
+
+  for (i = 0; i < NS_MAX; i++)
+    {
+      if (namespace[i])
+	{
+	  mu_list_t list;
+	  mu_list_create (&list);
+	  mu_list_set_destroy_item (list, free_item);
+	  mu_list_do (namespace[i], normalize_fun, list);
+	  mu_list_set_destroy_item (namespace[i], free_item);
+	  mu_list_destroy (&namespace[i]);
+	  namespace[i] = list;
+	}
+    }
+}
