@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2001, 2003, 2005, 2006,
-   2007 Free Software Foundation, Inc.
+   2007, 2008 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,46 +24,45 @@ static int select_flags;
 /* select          ::= "SELECT" SPACE mailbox  */
 
 int
-imap4d_select (struct imap4d_command *command, char *arg)
+imap4d_select (struct imap4d_command *command, imap4d_tokbuf_t tok)
 {
-  return imap4d_select0 (command, arg, MU_STREAM_RDWR);
+  if (imap4d_tokbuf_argc (tok) != 3)
+    return util_finish (command, RESP_BAD, "Invalid arguments");
+  return imap4d_select0 (command, imap4d_tokbuf_getarg (tok, IMAP4_ARG_1),
+			 MU_STREAM_RDWR);
 }
 
 /* This code is share with EXAMINE.  */
 int
-imap4d_select0 (struct imap4d_command *command, char *arg, int flags)
+imap4d_select0 (struct imap4d_command *command, const char *mboxname,
+		int flags)
 {
-  char *mailbox_name, *sp = NULL;
   int status;
-
+  char *mailbox_name;
+  
   /* FIXME: Check state.  */
 
-  mailbox_name = util_getword (arg, &sp);
-  util_unquote (&mailbox_name);
-  if (mailbox_name == NULL || *mailbox_name == '\0')
-    return util_finish (command, RESP_BAD, "Too few arguments");
-
   /* Even if a mailbox is selected, a SELECT EXAMINE or LOGOUT
      command MAY be issued without previously issuing a CLOSE command.
      The SELECT, EXAMINE, and LOGUT commands implictly close the
      currently selected mailbox without doing an expunge.  */
   if (mbox)
     {
-      mu_mailbox_save_attributes (mbox);
+      mu_mailbox_sync (mbox);
       mu_mailbox_close (mbox);
       mu_mailbox_destroy (&mbox);
       /* Destroy the old uid table.  */
       imap4d_sync ();
     }
 
-  if (strcmp (mailbox_name, "INBOX") == 0)
+  if (strcmp (mboxname, "INBOX") == 0)
     flags |= MU_STREAM_CREAT;
-  mailbox_name = namespace_getfullpath (mailbox_name, "/");
+  mailbox_name = namespace_getfullpath (mboxname, "/", NULL);
 
   if (!mailbox_name)
     return util_finish (command, RESP_NO, "Couldn't open mailbox");
 
-  if ((status = mu_mailbox_create (&mbox, mailbox_name)) == 0
+  if ((status = mu_mailbox_create_default (&mbox, mailbox_name)) == 0
       && (status = mu_mailbox_open (mbox, flags)) == 0)
     {
       select_flags = flags;
@@ -80,8 +79,10 @@ imap4d_select0 (struct imap4d_command *command, char *arg, int flags)
 			    "READ-ONLY" : "READ-WRITE", command->name);
 	}
     }
-  status = util_finish (command, RESP_NO, "Couldn't open %s, %s",
-			mailbox_name, mu_strerror (status));
+  
+  mu_mailbox_destroy (&mbox);
+  status = util_finish (command, RESP_NO, "Could not open %s: %s",
+			mboxname, mu_strerror (status));
   free (mailbox_name);
   return status;
 }
@@ -108,7 +109,7 @@ imap4d_select_status ()
 
   /* This outputs EXISTS and RECENT responses */
   imap4d_sync();
-  util_out (RESP_OK, "[UIDVALIDITY %d] UID valididy status", uidvalidity);
+  util_out (RESP_OK, "[UIDVALIDITY %lu] UID valididy status", uidvalidity);
   util_out (RESP_OK, "[UIDNEXT %d] Predicted next uid", uidnext);
   if (unseen)
     util_out (RESP_OK, "[UNSEEN %d] first unseen messsage ", unseen);
