@@ -1,9 +1,9 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2007, 2008, 2009 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Mailutils is distributed in the hope that it will be useful,
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -22,17 +23,26 @@
 static int tls_available;
 static int tls_done;
 
+/*
+6.2.1.  STARTTLS Command
+
+   Arguments:  none
+
+   Responses:  no specific response for this command
+
+   Result:     OK - starttls completed, begin TLS negotiation
+               BAD - command unknown or arguments invalid
+*/
 int
-imap4d_starttls (struct imap4d_command *command, char *arg)
+imap4d_starttls (struct imap4d_command *command, imap4d_tokbuf_t tok)
 {
   int status;
-  char *sp = NULL;
 
   if (!tls_available || tls_done)
     return util_finish (command, RESP_BAD, "Invalid command");
 
-  if (util_getword (arg, &sp))
-    return util_finish (command, RESP_BAD, "Too many args");
+  if (imap4d_tokbuf_argc (tok) != 2)
+    return util_finish (command, RESP_BAD, "Invalid arguments");
 
   util_atexit (mu_deinit_tls_libs);
 
@@ -52,9 +62,9 @@ imap4d_starttls (struct imap4d_command *command, char *arg)
     }
   else
     {
-      syslog (LOG_ERR, _("Session terminated"));
+      mu_diag_output (MU_DIAG_ERROR, _("session terminated"));
       util_bye ();
-      exit (0);
+      exit (EX_OK);
     }
 
   return status;
