@@ -28,18 +28,19 @@
 extern "C" {
 #endif
 
+extern char *mu_ticket_file;
+  
 int mu_set_mail_directory (const char *p);
+int mu_set_mailbox_pattern (const char *pat);
 void mu_set_folder_directory (const char *p);
-const char *mu_mail_directory (void);
+const char *mu_mailbox_url (void);
 const char *mu_folder_directory (void);
 int mu_construct_user_mailbox_url (char **pout, const char *name);
 
-/* Default mailbox protocol */
-int mu_mailbox_set_default_proto (const char *proto);
-const char *mu_mailbox_get_default_proto (void);
-  
 /* Constructor/destructor and possible types.  */
 extern int  mu_mailbox_create          (mu_mailbox_t *, const char *);
+extern int  mu_mailbox_create_from_url (mu_mailbox_t *, mu_url_t);
+
 extern void mu_mailbox_destroy         (mu_mailbox_t *);
 extern int  mu_mailbox_create_default  (mu_mailbox_t *, const char *);
 
@@ -52,13 +53,28 @@ extern int  mu_mailbox_uidvalidity     (mu_mailbox_t, unsigned long *);
 extern int  mu_mailbox_uidnext         (mu_mailbox_t, size_t *);
 
 /* Messages.  */
-extern int  mu_mailbox_get_message     (mu_mailbox_t, size_t msgno, mu_message_t *);
+extern int  mu_mailbox_get_message     (mu_mailbox_t, size_t msgno,
+					mu_message_t *);
+extern int  mu_mailbox_quick_get_message(mu_mailbox_t, mu_message_qid_t,
+					 mu_message_t *); 
 extern int  mu_mailbox_append_message  (mu_mailbox_t, mu_message_t);
 extern int  mu_mailbox_messages_count  (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_messages_recent (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_message_unseen  (mu_mailbox_t, size_t *);
 extern int  mu_mailbox_expunge         (mu_mailbox_t);
-extern int  mu_mailbox_save_attributes (mu_mailbox_t);
+extern int  mu_mailbox_sync            (mu_mailbox_t);  
+extern int  mu_mailbox_save_attributes (mu_mailbox_t)
+                                       __attribute__ ((deprecated));
+
+#define MU_UIDL_LENGTH 70
+#define MU_UIDL_BUFFER_SIZE (MU_UIDL_LENGTH+1)
+				       
+struct mu_uidl
+{
+  size_t msgno;
+  char uidl[MU_UIDL_BUFFER_SIZE];
+};
+extern int  mu_mailbox_get_uidls       (mu_mailbox_t, mu_list_t *);
 
 /* Update and scanning.  */
 extern int  mu_mailbox_get_size        (mu_mailbox_t, mu_off_t *size);
