@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2003,
-   2004, 2007, 2008 Free Software Foundation, Inc.
+   2004, 2007, 2008, 2009 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -34,7 +34,7 @@
 #include <mailutils/header.h>
 #include <mailutils/iterator.h>
 #include <mailutils/kwd.h>
-#include <mailutils/libsieve.h>
+#include <mailutils/sieve.h>
 #include <mailutils/list.h>
 #include <mailutils/locker.h>
 #include <mailutils/mailbox.h>
@@ -61,9 +61,9 @@
 #include <mailutils/gocs.h>
 #include <mailutils/version.h>
 #include <mailutils/vartab.h>
-
-#ifdef MU_COMPAT
-# error "Version 0.6 is no longer supported. Please, update your program."
-#endif
+#include <mailutils/io.h>
+#include <mailutils/secret.h>
+#include <mailutils/cctype.h>
+#include <mailutils/cstr.h>
 
 /* EOF */
