@@ -1,10 +1,10 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2005  Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005, 2007  Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,7 @@
 # define _MAILUTILS_STREAM_H
 
 #include <stdio.h>
-
+#include <stdarg.h>
 #include <mailutils/types.h>
 
 #ifdef __cplusplus
@@ -38,7 +38,15 @@ extern "C" { /*}*/
 #define MU_STREAM_SEEKABLE    0x00000080
 #define MU_STREAM_NO_CLOSE    0x00000100
 #define MU_STREAM_ALLOW_LINKS 0x00000200
-#define MU_STREAM_STRICT      0x00000400
+#define MU_STREAM_NONLOCK     0x00000400
+/* This one affects only mailboxes */  
+#define MU_STREAM_QACCESS     0x00000800
+  
+#define MU_STREAM_IRGRP       0x00001000
+#define MU_STREAM_IWGRP       0x00002000
+#define MU_STREAM_IROTH       0x00004000
+#define MU_STREAM_IWOTH       0x00008000
+#define MU_STREAM_IMASK       0x0000F000
   
 /* Functions useful to users of the pre-defined stream types. */
 
@@ -48,6 +56,17 @@ extern int mu_temp_file_stream_create (mu_stream_t *stream, const char *dir);
   
 extern int mu_tcp_stream_create     (mu_stream_t *stream, const char* host,
 				     int port, int flags);
+extern int mu_tcp_stream_create_with_source_ip (mu_stream_t *stream,
+						const char *host, int port,
+						unsigned long source_ip,
+						int flags);
+extern int mu_tcp_stream_create_with_source_host (mu_stream_t *stream,
+						  const char *host, int port,
+						  const char *source_host,
+						  int flags);
+extern int mu_socket_stream_create (mu_stream_t *stream, const char *filename,
+				    int flags);
+  
 extern int mu_mapfile_stream_create (mu_stream_t *stream, const char* filename,
 				     int flags);
 extern int mu_memory_stream_create  (mu_stream_t *stream, const char* filename,
@@ -74,15 +93,28 @@ extern int mu_stream_get_transport (mu_stream_t stream, mu_transport_t *pt);
 
 extern int mu_stream_read        (mu_stream_t, char *, size_t, mu_off_t, size_t *);
 extern int mu_stream_readline    (mu_stream_t, char *, size_t, mu_off_t, size_t *);
+extern int mu_stream_getline     (mu_stream_t is, char **pbuf, size_t *pbufsize,
+				  mu_off_t offset, size_t *pnread);
 extern int mu_stream_size        (mu_stream_t, mu_off_t *);
 extern int mu_stream_truncate    (mu_stream_t, mu_off_t);
 extern int mu_stream_write       (mu_stream_t, const char *, size_t, mu_off_t,
 				  size_t *);
 extern int mu_stream_setbufsiz   (mu_stream_t stream, size_t size);
 extern int mu_stream_flush       (mu_stream_t);
+extern int mu_stream_shutdown    (mu_stream_t stream, int how);
+
+extern int mu_stream_vprintf     (mu_stream_t os, mu_off_t *poff, 
+                                  const char *fmt, va_list ap);
+extern int mu_stream_printf      (mu_stream_t stream, mu_off_t *off, 
+                                  const char *fmt, ...) MU_PRINTFLIKE(3,4);
+extern int mu_stream_sequential_vprintf (mu_stream_t stream, const char *fmt,
+                                         va_list ap);
+extern int mu_stream_sequential_printf (mu_stream_t stream, const char *fmt,
+                                        ...) MU_PRINTFLIKE(2,3);
 
 #define MU_STREAM_READY_RD 0x1
 #define MU_STREAM_READY_WR 0x2
+#define MU_STREAM_READY_EX 0x4  
 struct timeval;  /* Needed for the following declaration */ 
 
 extern int mu_stream_wait        (mu_stream_t stream, int *pflags, struct timeval *);
@@ -145,12 +177,18 @@ extern int mu_stream_set_strerror (mu_stream_t stream,
 
 extern int mu_stream_set_wait (mu_stream_t stream,
       int (*wait) (mu_stream_t, int *, struct timeval *), void *owner);
+
+extern int mu_stream_set_shutdown (mu_stream_t stream,
+      int (*_shutdown) (mu_stream_t, int how), void *owner);
   
 extern int mu_stream_sequential_read (mu_stream_t stream,
       char *buf, size_t size, size_t *nbytes);
   
 extern int mu_stream_sequential_readline (mu_stream_t stream,
       char *buf, size_t size, size_t *nbytes);
+
+extern int mu_stream_sequential_getline  (mu_stream_t is,
+      char **pbuf, size_t *pbufsize, size_t *pnread);
   
 extern int mu_stream_sequential_write (mu_stream_t stream,
 				    const char *buf, size_t size);
