@@ -1,9 +1,10 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2005  Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005, 2007, 2009
+   Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Mailutils is distributed in the hope that it will be useful,
@@ -24,10 +25,10 @@
 #define USE_DBM
 typedef GDBM_FILE DBM_FILE;
 typedef datum DBM_DATUM;
-#define MU_DATUM_SIZE(d) d.dsize
-#define MU_DATUM_PTR(d) d.dptr
+#define MU_DATUM_SIZE(d) (d).dsize
+#define MU_DATUM_PTR(d) (d).dptr
 
-#elif defined(WITH_BDB2)
+#elif defined(WITH_BDB)
 
 #include <db.h>
 #define USE_DBM
@@ -40,8 +41,8 @@ struct db2_file
 
 typedef struct db2_file *DBM_FILE;
 typedef DBT DBM_DATUM;
-#define MU_DATUM_SIZE(d) d.size
-#define MU_DATUM_PTR(d) d.data
+#define MU_DATUM_SIZE(d) (d).size
+#define MU_DATUM_PTR(d) (d).data
 
 #elif defined(WITH_NDBM)
 
@@ -49,17 +50,29 @@ typedef DBT DBM_DATUM;
 #define USE_DBM
 typedef DBM *DBM_FILE;
 typedef datum DBM_DATUM;
-#define MU_DATUM_SIZE(d) d.dsize
-#define MU_DATUM_PTR(d) d.dptr
+#define MU_DATUM_SIZE(d) (d).dsize
+#define MU_DATUM_PTR(d) (d).dptr
 
-#elif defined(WITH_OLD_DBM)
+#elif defined(WITH_TOKYOCABINET)
 
-#include <dbm.h>
+#include <tcutil.h>
+#include <tchdb.h>
 #define USE_DBM
-typedef int DBM_FILE;
-typedef datum DBM_DATUM;
-#define MU_DATUM_SIZE(d) d.dsize
-#define MU_DATUM_PTR(d) d.dptr
+
+struct tokyocabinet_file
+{
+  TCHDB *hdb;
+};
+
+struct tokyocabinet_datum {
+  void *data;
+  int size;
+};
+
+typedef struct tokyocabinet_file *DBM_FILE;
+typedef struct tokyocabinet_datum DBM_DATUM;
+#define MU_DATUM_SIZE(d) (d).size
+#define MU_DATUM_PTR(d) (d).data
 
 #endif
 
@@ -73,7 +86,8 @@ int mu_dbm_insert (DBM_FILE db, DBM_DATUM key, DBM_DATUM contents, int replace);
 int mu_dbm_delete (DBM_FILE db, DBM_DATUM key);
 DBM_DATUM mu_dbm_firstkey (DBM_FILE db);
 DBM_DATUM mu_dbm_nextkey (DBM_FILE db, DBM_DATUM key);
-#endif
+void mu_dbm_datum_free(DBM_DATUM *datum);
+#endif /* USE_DBM */
 
 int mu_fcheck_perm (int fd, int mode);
 int mu_check_perm (const char *name, int mode);
