@@ -25,6 +25,7 @@ long mailbox_tag;
 struct mu_mailbox
 {
   mu_mailbox_t mbox;       /* Mailbox */
+  int noclose;
 };
 
 /* SMOB functions: */
@@ -38,8 +39,11 @@ static scm_sizet
 mu_scm_mailbox_free (SCM mailbox_smob)
 {
   struct mu_mailbox *mum = (struct mu_mailbox *) SCM_CDR (mailbox_smob);
-  mu_mailbox_close (mum->mbox);
-  mu_mailbox_destroy (&mum->mbox);
+  if (!mum->noclose)
+    {
+      mu_mailbox_close (mum->mbox);
+      mu_mailbox_destroy (&mum->mbox);
+    }
   free (mum);
   /* NOTE: Currently there is no way for this function to return the
      amount of memory *actually freed* by mu_mailbox_destroy */
@@ -85,16 +89,38 @@ mu_scm_mailbox_print (SCM mailbox_smob, SCM port, scm_print_state * pstate)
 
 /* Internal functions */
 
+/* There are two C interfaces for creating mailboxes in Scheme.
+   The first one, mu_scm_mailbox_create0, allows to set `noclose'
+   bit, which disables closing and releasing the underlying mu_mailbox_t
+   after the hosting SCM object is freed. Use this, if this mailbox
+   is referenced elsewhere.
+
+   Another one, mu_scm_mailbox_create, always create an object that
+   will cause closing the mu_mailbox_t object and releasing its memory
+   after the hosting SCM object is swept away by GC. This is the only
+   official one.
+
+   The mu_scm_mailbox_create0 function is a kludge, needed because
+   mu_mailbox_t objects don't have reference counters. When it is fixed in
+   the library, the interface will be removed. */
+
 SCM
-mu_scm_mailbox_create (mu_mailbox_t mbox)
+mu_scm_mailbox_create0 (mu_mailbox_t mbox, int noclose)
 {
   struct mu_mailbox *mum;
 
   mum = scm_gc_malloc (sizeof (struct mu_mailbox), "mailbox");
   mum->mbox = mbox;
+  mum->noclose = noclose;
   SCM_RETURN_NEWSMOB (mailbox_tag, mum);
 }
 
+SCM
+mu_scm_mailbox_create (mu_mailbox_t mbox)
+{
+  return mu_scm_mailbox_create0 (mbox, 0);
+}
+
 int
 mu_scm_is_mailbox (SCM scm)
 {
@@ -106,16 +132,34 @@ mu_scm_is_mailbox (SCM scm)
 
 SCM_DEFINE (scm_mu_mail_directory, "mu-mail-directory", 0, 1, 0,
 	    (SCM URL), 
-"If URL is given, sets it as a name of the user's mail directory.\n"
-"Returns the current value of the mail directory.")
+"Do not use this function. Use mu-user-mailbox-url instead.")
 #define FUNC_NAME s_scm_mu_mail_directory
 {
-  if (!SCM_UNBNDP (URL))
-    {
-      SCM_ASSERT (scm_is_string (URL), URL, SCM_ARG1, FUNC_NAME);
-      mu_set_mail_directory (scm_i_string_chars (URL));
-    }
-  return scm_makfrom0str (mu_mail_directory ());
+  mu_scm_error (FUNC_NAME, ENOSYS,
+		"This function is deprecated. Use mu-user-mailbox-url instead.",
+		  scm_list_1 (URL));
+  return SCM_EOL;
+}
+#undef FUNC_NAME 
+
+SCM_DEFINE (scm_mu_user_mailbox_url, "mu-user-mailbox-url", 1, 0, 0, 
+	    (SCM USER),
+	    "")
+#define FUNC_NAME s_scm_mu_user_mailbox_url
+{
+  int rc;
+  char *p;
+  SCM ret;
+  
+  SCM_ASSERT (scm_is_string (USER), USER, SCM_ARG1, FUNC_NAME);
+  rc = mu_construct_user_mailbox_url (&p, scm_i_string_chars (USER));
+  if (rc)
+    mu_scm_error (FUNC_NAME, rc,
+		  "Cannot construct mailbox URL for ~A",
+		  scm_list_1 (USER));
+  ret = scm_makfrom0str (p);
+  free (p);
+  return ret;
 }
 #undef FUNC_NAME 
 
