@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2006, 2007, 
+   2009 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -26,6 +27,7 @@
 #include <errno.h>
 #include <sys/time.h>
 #include <string.h>
+#include <confpaths.h>
 
 #include <mailutils/mailbox.h>
 #include <mailutils/message.h>
@@ -46,7 +48,7 @@
 #include <mailutils/mime.h>
 #include <mailutils/registrar.h>
 #include <mailutils/mu_auth.h>
+#include <mailutils/cstr.h>
 
 #include <mailutils/guile.h>
 
-
