@@ -24,6 +24,7 @@
 #endif
 
 #include <mailutils/debug.h>
+#include <mailutils/stream.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -32,10 +33,13 @@ extern "C" {
 struct _mu_debug
 {
   size_t level;
-  char *buffer;
-  size_t buflen;
+  mu_stream_t stream;
   void *owner;
-  int (*_print) (mu_debug_t, size_t level, const char *, va_list);
+  struct mu_debug_locus locus;
+  const char *function;
+  void *data;
+  mu_debug_printer_fp printer;
+  void (*destroy) (void *data);
 };
 
 #ifdef __cplusplus
