@@ -1,9 +1,9 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2005, 2007 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    GNU Mailutils is distributed in the hope that it will be useful,
@@ -23,7 +23,7 @@
  */
 
 int
-mail_inc (int argc ARG_UNUSED, char **argv ARG_UNUSED)
+mail_inc (int argc MU_ARG_UNUSED, char **argv MU_ARG_UNUSED)
 {
   if (!mu_mailbox_is_updated (mbox))
     {
