@@ -41,7 +41,7 @@ mail_mbox_close ()
   if (!mbox)
     return 0;
 
-  if (util_getenv (NULL, "readonly", Mail_env_boolean, 0))
+  if (mailvar_get (NULL, "readonly", mailvar_type_boolean, 0))
     {
       if (mail_mbox_commit ())
 	return 1;
@@ -55,7 +55,7 @@ mail_mbox_close ()
            ngettext ("Held %d message in %s\n",
                      "Held %d messages in %s\n",
                      held_count),
-           held_count, mu_url_to_string (url));
+           held_count, util_url_to_string (url));
   mu_mailbox_close (mbox);
   mu_mailbox_destroy (&mbox);
   return 0;
@@ -69,13 +69,13 @@ mail_mbox_commit ()
   int saved_count = 0;
   mu_message_t msg;
   mu_attribute_t attr;
-  int keepsave = util_getenv (NULL, "keepsave", Mail_env_boolean, 0) == 0;
-  int hold = util_getenv (NULL, "hold", Mail_env_boolean, 0) == 0;
+  int keepsave = mailvar_get (NULL, "keepsave", mailvar_type_boolean, 0) == 0;
+  int hold = mailvar_get (NULL, "hold", mailvar_type_boolean, 0) == 0;
   mu_url_t url;
   int is_user_mbox;
 
   mu_mailbox_get_url (mbox, &url);
-  is_user_mbox = strcmp (mu_url_to_string (url), getenv ("MBOX")) == 0;
+  is_user_mbox = strcmp (util_url_to_string (url), getenv ("MBOX")) == 0;
 
   {
     mu_mailbox_t mb;
@@ -87,6 +87,7 @@ mail_mbox_commit ()
 	/* The mailbox we are closing is not a system one (%). Raise
 	   hold flag */
 	hold = 1;
+	keepsave = 1;
       }
     mu_mailbox_destroy (&mb);
   }
@@ -102,7 +103,12 @@ mail_mbox_commit ()
 	  && (mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_MBOXED)
 	      || (!hold
 		  && !mu_attribute_is_deleted (attr)
-		  && mu_attribute_is_read (attr))))
+		  && !mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_PRESERVED)
+		  && ((mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_SAVED)
+		       && keepsave)
+		      || (!mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_SAVED)
+			  && (mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_SHOWN)
+			      || mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_TOUCHED)))))))
 	{
 	  int status;
 	  
@@ -136,7 +142,9 @@ mail_mbox_commit ()
 	}
       else if (mu_attribute_is_deleted (attr))
 	/* Skip this one */;
-      else if (!keepsave && mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_SAVED))
+      else if (!keepsave
+	       && !mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_PRESERVED)
+	       && mu_attribute_is_userflag (attr, MAIL_ATTRIBUTE_SAVED))
 	mu_attribute_set_deleted (attr);
       else if (mu_attribute_is_read (attr))
 	mu_attribute_set_seen (attr);
@@ -151,7 +159,7 @@ mail_mbox_commit ()
               ngettext ("Saved %d message in %s\n",
                         "Saved %d messages in %s\n",
 			saved_count),
-              saved_count, mu_url_to_string (u));
+              saved_count, util_url_to_string (u));
       mu_mailbox_close (dest_mbox);
       mu_mailbox_destroy (&dest_mbox);
     }
