@@ -85,7 +85,7 @@
 #line 1 "cfg_parser.y"
 
 /* cfg_parser.y -- general-purpose configuration file parser 
-   Copyright (C) 2007, 2008 Free Software Foundation, Inc.
+   Copyright (C) 2007, 2008, 2009 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -1604,7 +1604,7 @@ mu_cfg_yyreduce:
 		val.v.arg.v = mu_alloc (n * sizeof (val.v.arg.v[0]));
 		if (!val.v.arg.v)
 		  {
-		    mu_cfg_perror (&mu_cfg_locus, _("Not enough memory"));
+		    mu_cfg_perror (&mu_cfg_locus, _("not enough memory"));
 		    abort();
 		  }
 		
@@ -1626,7 +1626,7 @@ mu_cfg_yyreduce:
 	      int rc = mu_list_create (&(mu_cfg_yyval.list));
 	      if (rc)
 		{
-		  mu_cfg_perror (&mu_cfg_locus, _("Cannot create list: %s"),
+		  mu_cfg_perror (&mu_cfg_locus, _("cannot create list: %s"),
 				 mu_strerror (rc));
 		  abort ();
 		}
