@@ -42,7 +42,7 @@ pthread_mutex_t monitor_lock = PTHREAD_MUTEX_INITIALIZER;
 #  define STATIC_UNLOCK(m) pthread_mutex_unlock(m)
 #else
 #  define STATIC_LOCK(m) 0
-#  define STATIC_UNLOCK(m) 
+#  define STATIC_UNLOCK(m)
 int monitor_lock;
 #endif
 
@@ -212,29 +212,23 @@ mu_monitor_notify (mu_monitor_t monitor MU_ARG_UNUSED)
 #    define RWLOCK_INIT(rwl, attr)  pthread_rwlock_init (rwl, attr)
 #    define RWLOCK_DESTROY(rwl)     pthread_rwlock_destroy (rwl)
 #    define RWLOCK_RDLOCK(rwl)      pthread_rwlock_rdlock (rwl)
-#    define RWLOCK_TRYRDLOCK(rwl)   pthread_rwlock_tryrdlock (rwl)
 #    define RWLOCK_WRLOCK(rwl)      pthread_rwlock_wrlock (rwl)
-#    define RWLOCK_TRYWRLOCK(rwl)   pthread_rwlock_trywrlock (rwl)
 #    define RWLOCK_UNLOCK(rwl)      pthread_rwlock_unlock (rwl)
 #  else
 #    define RWLOCK_INIT(rwl, attr)  pthread_mutex_init (rwl, attr)
 #    define RWLOCK_DESTROY(rwl)     pthread_mutex_destroy (rwl)
 #    define RWLOCK_RDLOCK(rwl)      pthread_mutex_lock (rwl)
-#    define RWLOCK_TRYRDLOCK(rwl)   pthread_mutex_trylock (rwl)
 #    define RWLOCK_WRLOCK(rwl)      pthread_mutex_lock (rwl)
-#    define RWLOCK_TRYWRLOCK(rwl)   pthread_mutex_trylock (rwl)
 #    define RWLOCK_UNLOCK(rwl)      pthread_mutex_unlock (rwl)
 #  endif
 #else
 #  define RWLOCK_INIT(rwl, attr)    0
-#  define RWLOCK_DESTROY(rwl)       0
+#  define RWLOCK_DESTROY(rwl)
 #  define RWLOCK_RDLOCK(rwl)        0
-#  define RWLOCK_TRYRDLOCK(rwl)     0
 #  define RWLOCK_WRLOCK(rwl)        0
-#  define RWLOCK_TRYWRLOCK(rwl)     0
 #  define RWLOCK_UNLOCK(rwl)        0
-#  define flockfile(arg)            0
-#  define funlockfile(arg)          0
+#  define flockfile(arg)
+#  define funlockfile(arg)
 #endif
 
 
