@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2003,
-   2005, 2006, 2007 Free Software Foundation, Inc.
+   2005, 2006, 2007, 2009 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -60,6 +60,9 @@
 #include <mailutils/filter.h>
 #include <mailutils/sql.h>
 #include <mailutils/url.h>
+#include <mailutils/io.h>
+#include <mailutils/cctype.h>
+#include <mailutils/cstr.h>
 
 #include <registrar0.h>
 
@@ -436,7 +439,7 @@ mu_aget_user_email_domain (char **pdomain)
   if (status)
     return status;
   if (domain == NULL)
-    *pdomain = domain;
+    *pdomain = NULL;
   else
     {
       *pdomain = strdup (domain);
@@ -611,7 +614,7 @@ mu_tempfile (const char *tmpdir, char **namep)
 
   if (fd == -1)
     {
-      mu_error (_("Cannot open temporary file: %s"), strerror (errno));
+      mu_error (_("cannot open temporary file: %s"), mu_strerror (errno));
       free (filename);
       return -1;
     }
@@ -818,10 +821,10 @@ mu_unroll_symlink (char *out, size_t outsz, const char *in)
 char *
 mu_expand_path_pattern (const char *pattern, const char *username)
 {
-  const char *p, *startp;
+  const char *p;
   char *q;
   char *path;
-  int len = 0;
+  size_t len = 0;
   struct mu_auth_data *auth = NULL;
   
   for (p = pattern; *p; p++)
@@ -868,39 +871,46 @@ mu_expand_path_pattern (const char *pattern, const char *username)
   if (!path)
     return NULL;
 
-  startp = pattern;
+  p = pattern;
   q = path;
-  while (*startp && (p = strchr (startp, '%')) != NULL)
+  while (*p)
     {
-      memcpy (q, startp, p - startp);
-      q += p - startp;
-      switch (*++p)
+      size_t off = strcspn (p, "~%");
+      memcpy (q, p, off);
+      q += off;
+      p += off;
+      if (*p == '~')
 	{
-	case 'u':
-	  strcpy (q, username);
-	  q += strlen (username);
-	  break;
-	  
-	case 'h':
 	  strcpy (q, auth->dir);
 	  q += strlen (auth->dir);
-	  break;
+	  p++;
+	}
+      else if (*p == '%')
+	{
+	  switch (*++p)
+	    {
+	    case 'u':
+	      strcpy (q, username);
+	      q += strlen (username);
+	      break;
+	    
+	    case 'h':
+	      strcpy (q, auth->dir);
+	      q += strlen (auth->dir);
+	      break;
 	  
-	case '%':
-	  *q++ = '%';
-	  break;
+	    case '%':
+	      *q++ = '%';
+	      break;
 	  
-	default:
-	  *q++ = '%';
-	  *q++ = *p;
+	    default:
+	      *q++ = '%';
+	      *q++ = *p;
+	    }
+	  p++;
 	}
-      startp = p + 1;
-    }
-  if (*startp)
-    {
-      strcpy (q, startp);
-      q += strlen (startp);
     }
+
   *q = 0;
   if (auth)
     mu_auth_data_free (auth);
@@ -1031,14 +1041,14 @@ mu_rfc2822_msg_id (int subpart, char **pval)
     {
       struct timeval tv;
       gettimeofday (&tv, NULL);
-      asprintf (&p, "<%s.%lu.%d@%s>",
-		date,
-		(unsigned long) getpid (),
-		subpart,
-		host);
+      mu_asprintf (&p, "<%s.%lu.%d@%s>",
+		   date,
+		   (unsigned long) getpid (),
+		   subpart,
+		   host);
     }
   else
-    asprintf (&p, "<%s.%lu@%s>", date, (unsigned long) getpid (), host);
+    mu_asprintf (&p, "<%s.%lu@%s>", date, (unsigned long) getpid (), host);
   free (host);
   *pval = p;
   return 0;
@@ -1114,7 +1124,7 @@ mu_strcasestr (const char *a_haystack, const char *a_needle)
     *needle = (unsigned char*) a_needle;
   register unsigned int b, c;
 
-#define U(c) toupper (c)
+#define U(c) mu_toupper (c)
   if ((b = U (*needle)))
     {
       haystack--;		
@@ -1295,10 +1305,10 @@ mu_fd_wait (int fd, int *pflags, struct timeval *tvp)
       if (tvp)
 	{
 	  struct timeval tv = *tvp; 
-	  rc = select (fd + 1, &rdset, &wrset, NULL, &tv);
+	  rc = select (fd + 1, &rdset, &wrset, &exset, &tv);
 	}
       else
-	rc = select (fd + 1, &rdset, &wrset, NULL, NULL);
+	rc = select (fd + 1, &rdset, &wrset, &exset, NULL);
     }
   while (rc == -1 && errno == EINTR);
 
@@ -1346,7 +1356,7 @@ mu_decode_filter (mu_stream_t *pfilter, mu_stream_t input,
   if (status)
     return status;
 
-  if (fromcode && tocode && strcasecmp (fromcode, tocode))
+  if (fromcode && tocode && mu_c_strcasecmp (fromcode, tocode))
     {
       mu_stream_t cvt;
       status = mu_filter_iconv_create (&cvt, filter, fromcode, tocode,
