@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2004, 2005, 2006,
-   2007 Free Software Foundation, Inc.
+   2007, 2009 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -35,7 +35,7 @@
 #include <mailutils/nls.h>
 #include <mailutils/error.h>
 #include <mailutils/url.h>
-
+#include <mailutils/mutil.h>
 #include <registrar0.h>
 
 /* NOTE: We will leak here since the monitor and the registrar will never
@@ -43,6 +43,44 @@
 static mu_list_t registrar_list;
 struct mu_monitor registrar_monitor = MU_MONITOR_INITIALIZER;
 
+static mu_record_t mu_default_record;
+
+void
+mu_registrar_set_default_record (mu_record_t record)
+{
+  mu_default_record = record;
+}
+
+int
+mu_registrar_get_default_record (mu_record_t *prec)
+{
+  if (mu_default_record)
+    {
+      if (prec)
+	*prec = mu_default_record;
+      return 0;
+    }
+  return MU_ERR_NOENT;
+}
+
+int
+mu_registrar_set_default_scheme (const char *scheme)
+{
+  int status;
+  mu_record_t rec;
+  
+  status = mu_registrar_lookup_scheme (scheme, &rec);
+  if (status == 0)
+    mu_default_record = rec;
+  return status;
+}
+
+const char *
+mu_registrar_get_default_scheme ()
+{
+  return mu_default_record ? mu_default_record->scheme : NULL;
+}
+
 static int
 _registrar_get_list (mu_list_t *plist)
 {
@@ -66,7 +104,7 @@ mu_registrar_get_list (mu_list_t *plist)
 
   if (!warned)
     {
-      mu_error (_("Program uses mu_registrar_get_list(), which is deprecated"));
+      mu_error (_("program uses mu_registrar_get_list(), which is deprecated"));
       warned = 1;
     }
   return _registrar_get_list (plist);
@@ -90,11 +128,41 @@ mu_registrar_get_iterator (mu_iterator_t *pitr)
   return status;
 }
 
+int
+mu_registrar_lookup_scheme (const char *scheme, mu_record_t *precord)
+{
+  size_t len;
+  mu_iterator_t iterator;
+  int status = mu_registrar_get_iterator (&iterator);
+  if (status != 0)
+    return status;
+  status = MU_ERR_NOENT;
+  len = strcspn (scheme, ":");
+  for (mu_iterator_first (iterator); !mu_iterator_is_done (iterator);
+       mu_iterator_next (iterator))
+    {
+      mu_record_t record;
+      mu_iterator_current (iterator, (void **)&record);
+      if (strlen (record->scheme) == len
+	  && memcmp (record->scheme, scheme, len) == 0)
+	{
+	  if (precord)
+	    *precord = record;
+	  status = 0;
+	  break;
+	}
+    }
+  mu_iterator_destroy (&iterator);
+  return status;
+}
+
 int
 mu_registrar_lookup_url (mu_url_t url, int flags,
 			 mu_record_t *precord, int *pflags)
 {
   mu_iterator_t iterator;
+  mu_record_t last_record = NULL;
+  int last_flags = 0;
   int status = mu_registrar_get_iterator (&iterator);
   if (status != 0)
     return status;
@@ -107,15 +175,39 @@ mu_registrar_lookup_url (mu_url_t url, int flags,
       mu_iterator_current (iterator, (void **)&record);
       if ((rc = mu_record_is_scheme (record, url, flags)))
 	{
-	  status = 0;
-	  if (precord)
-	    *precord = record;
-	  if (pflags)
-	    *pflags = rc;
-	  break;
+	  if (rc == flags)
+	    {
+	      status = 0;
+	      last_record = record;
+	      last_flags = rc;
+	      break;
+	    }
+	  else if (rc > last_flags)
+	    {
+	      status = 0;
+	      last_record = record;
+	      last_flags = rc;
+	    }
 	}
     }
   mu_iterator_destroy (&iterator);
+
+  if (status == 0)
+    {
+      if (precord)
+	*precord = last_record;
+      if (pflags)
+	*pflags = last_flags;
+    }
+  else if (!mu_is_proto (mu_url_to_string (url)) /* FIXME: This check is not
+						    enough. */
+	   && mu_registrar_get_default_record (precord) == 0)
+    {
+      status = 0;
+      if (pflags)
+	*pflags = flags & MU_FOLDER_ATTRIBUTE_FILE; /* FIXME? */
+    }
+  
   return status;
 }
 
@@ -339,3 +431,13 @@ mu_record_set_get_folder (mu_record_t record,
   record->_get_folder = _get_folder;
   return 0;
 }
+
+int
+mu_record_list_p (mu_record_t record, const char *name, int flags)
+{
+  if (record == NULL)
+    return EINVAL;
+  return record == NULL
+          || !record->_list_p
+          || record->_list_p (record, name, flags);
+}
