@@ -1,10 +1,10 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2002 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2007 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -40,7 +40,6 @@
 #include <mailutils/list.h>
 #include <mailutils/iterator.h>
 #include <mailutils/mailbox.h>
-#include <mailutils/argp.h>
 #include <mailutils/mu_auth.h>
 #include <mailutils/errno.h>
 
@@ -75,8 +74,8 @@ mu_auth_system (struct mu_auth_data **return_data, const struct passwd *pw)
 int
 mu_auth_system_by_name (struct mu_auth_data **return_data,
 			const void *key,
-			void *func_data ARG_UNUSED,
-			void *call_data ARG_UNUSED)
+			void *func_data MU_ARG_UNUSED,
+			void *call_data MU_ARG_UNUSED)
 {
   if (!key)
     return EINVAL;
@@ -86,8 +85,8 @@ mu_auth_system_by_name (struct mu_auth_data **return_data,
 static int
 mu_auth_system_by_uid (struct mu_auth_data **return_data,
 		       const void *key,
-		       void *func_data ARG_UNUSED,
-		       void *call_data ARG_UNUSED)
+		       void *func_data MU_ARG_UNUSED,
+		       void *call_data MU_ARG_UNUSED)
 {
   if (!key)
     return EINVAL;
@@ -95,9 +94,9 @@ mu_auth_system_by_uid (struct mu_auth_data **return_data,
 }
 
 static int
-mu_authenticate_generic (struct mu_auth_data **return_data ARG_UNUSED,
+mu_authenticate_generic (struct mu_auth_data **return_data MU_ARG_UNUSED,
 			 const void *key,
-			 void *func_data ARG_UNUSED,
+			 void *func_data MU_ARG_UNUSED,
 			 void *call_data)
 {
   const struct mu_auth_data *auth_data = key;
@@ -113,9 +112,9 @@ mu_authenticate_generic (struct mu_auth_data **return_data ARG_UNUSED,
 
 /* Called only if generic fails */
 static int
-mu_authenticate_system (struct mu_auth_data **return_data ARG_UNUSED,
+mu_authenticate_system (struct mu_auth_data **return_data MU_ARG_UNUSED,
 			const void *key,
-			void *func_data ARG_UNUSED,
+			void *func_data MU_ARG_UNUSED,
 			void *call_data)
 {
   const struct mu_auth_data *auth_data = key;
