@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2005, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2005, 2006, 2007, 
+   2008, 2009 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,48 +30,48 @@ static char args_doc[] = "[msgs]";
 /* GNU options */
 static struct argp_option options[] = {
   {"annotate",      ARG_ANNOTATE,      N_("BOOL"), OPTION_ARG_OPTIONAL,
-   N_("Add Forwarded: header to each forwarded message")},
+   N_("add Forwarded: header to each forwarded message")},
   {"build",         ARG_BUILD,         0, 0,
-   N_("Build the draft and quit immediately")},
+   N_("build the draft and quit immediately")},
   {"draftfolder",   ARG_DRAFTFOLDER,   N_("FOLDER"), 0,
-   N_("Specify the folder for message drafts")},
+   N_("specify the folder for message drafts")},
   {"nodraftfolder", ARG_NODRAFTFOLDER, 0, 0,
-   N_("Undo the effect of the last --draftfolder option")},
+   N_("undo the effect of the last --draftfolder option")},
   {"draftmessage" , ARG_DRAFTMESSAGE,  N_("MSG"), 0,
-   N_("Invoke the draftmessage facility")},
+   N_("invoke the draftmessage facility")},
   {"folder",        ARG_FOLDER,        N_("FOLDER"), 0,
-   N_("Specify folder to operate upon")},
+   N_("specify folder to operate upon")},
   {"editor",        ARG_EDITOR,        N_("PROG"), 0,
-   N_("Set the editor program to use")},
+   N_("set the editor program to use")},
   {"noedit",        ARG_NOEDIT,        0, 0,
-   N_("Suppress the initial edit")},
+   N_("suppress the initial edit")},
   {"format",        ARG_FORMAT,        N_("BOOL"), 0, 
-   N_("Format messages")},
+   N_("format messages")},
   {"noformat",      ARG_NOFORMAT,      NULL, 0,
-   N_("Undo the effect of the last --format option") },
+   N_("undo the effect of the last --format option") },
   {"form",          ARG_FORM,          N_("FILE"), 0,
-   N_("Read format from given file")},
+   N_("read format from given file")},
   {"filter",        ARG_FILTER,        N_("FILE"), 0,
-  N_("Use filter FILE to preprocess the body of the message") },
+  N_("use filter FILE to preprocess the body of the message") },
   {"nofilter",      ARG_NOFILTER,      NULL, 0,
-   N_("Undo the effect of the last --filter option") },
+   N_("undo the effect of the last --filter option") },
   {"inplace",       ARG_INPLACE,       N_("BOOL"), OPTION_ARG_OPTIONAL,
-   N_("* Annotate the message in place")},
+   N_("* annotate the message in place")},
   {"noinplace",     ARG_NOINPLACE,     0,          OPTION_HIDDEN, "" },
   {"mime",          ARG_MIME,          N_("BOOL"), OPTION_ARG_OPTIONAL,
-   N_("Use MIME encapsulation") },
+   N_("use MIME encapsulation") },
   {"nomime",        ARG_NOMIME,        NULL, OPTION_HIDDEN, "" },
   {"width", ARG_WIDTH, N_("NUMBER"), 0, N_("Set output width")},
   {"whatnowproc",   ARG_WHATNOWPROC,   N_("PROG"), 0,
-   N_("* Set the replacement for whatnow program")},
+   N_("* set the replacement for whatnow program")},
   {"nowhatnowproc", ARG_NOWHATNOWPROC, NULL, 0,
-   N_("* Ignore whatnowproc variable. Use standard `whatnow' shell instead")},
+   N_("* ignore whatnowproc variable, use standard `whatnow' shell instead")},
   {"use",           ARG_USE,           N_("BOOL"), OPTION_ARG_OPTIONAL,
-   N_("Use draft file preserved after the last session") },
+   N_("use draft file preserved after the last session") },
   {"nouse",         ARG_NOUSE,         N_("BOOL"), OPTION_HIDDEN, "" },
 
   {"license", ARG_LICENSE, 0,      0,
-   N_("Display software license"), -1},
+   N_("display software license"), -1},
 
   {NULL},
 };
@@ -157,7 +158,7 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
       width = strtoul (arg, NULL, 0);
       if (!width)
 	{
-	  argp_error (state, _("Invalid width"));
+	  argp_error (state, _("invalid width"));
 	  exit (1);
 	}
       break;
@@ -205,7 +206,7 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
     case ARG_INPLACE:
     case ARG_WHATNOWPROC:
     case ARG_NOWHATNOWPROC:
-      argp_error (state, _("Option is not yet implemented"));
+      argp_error (state, _("option is not yet implemented"));
       exit (1);
       
     case ARG_LICENSE:
@@ -339,7 +340,7 @@ finish_draft ()
 				   MU_STREAM_WRITE|MU_STREAM_CREAT)) != 0
       || (rc = mu_stream_open (stream)))
     {
-      mu_error (_("Cannot open output file `%s': %s"),
+      mu_error (_("cannot open output file `%s': %s"),
 		wh_env.file, mu_strerror (rc));
       exit (1);
     }
@@ -423,9 +424,9 @@ main (int argc, char **argv)
   int index, rc;
 
   /* Native Language Support */
-  mu_init_nls ();
+  MU_APP_INIT_NLS ();
 
-  mu_argp_init (program_version, NULL);
+  mh_argp_init (program_version);
   mh_argp_parse (&argc, &argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, &index);
 
@@ -469,7 +470,7 @@ main (int argc, char **argv)
   
   rc = mh_whatnow (&wh_env, initial_edit);
 
-  mu_mailbox_save_attributes (mbox);
+  mu_mailbox_sync (mbox);
   mu_mailbox_close (mbox);
   mu_mailbox_destroy (&mbox);
   return rc;
